ModuleInfo class

Constructors

ModuleInfo({required String name, required Module module, required bool isActive, required bool isCurrent})
const

Properties

dependencies → List<Object>
no setter
dependencyCount → int
no setter
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasStack → bool
no setter
isActive → bool
final
isCurrent → bool
final
isFullScreen → bool
no setter
lastError → Object?
no setter
module → Module
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stack → Iterable<Widget>
no setter
stackDepth → int
no setter
stateColor → Color
no setter
stateIcon → IconData
no setter
stateText → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited